=========
RL-Agents
=========


.. image:: https://img.shields.io/pypi/v/rl-agents.svg
        :target: https://pypi.python.org/pypi/rl-agents

.. image:: https://travis-ci.org/mateuspontesm/rl-agents.svg?branch=master
        :target: https://travis-ci.org/mateuspontesm/rl-agents
        :alt: Travis-CI Build Status

.. image:: https://readthedocs.org/projects/rl-agents/badge/?version=latest
        :target: https://rl-agents.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://coveralls.io/repos/mateuspontesm/rl-agents/badge.svg?branch=master&service=github
        :alt: Coverage Status
        :target: https://coveralls.io/r/mateuspontesm/rl-agents

.. image:: https://codecov.io/gh/mateuspontesm/rl-agents/branch/master/graphs/badge.svg?branch=master
        :alt: Coverage Status
        :target: https://codecov.io/github/mateuspontesm/rl-agents

.. image:: https://img.shields.io/scrutinizer/quality/g/mateuspontesm/rl-agents/master.svg
        :alt: Scrutinizer Status
        :target: https://scrutinizer-ci.com/g/mateuspontesm/rl-agents/

.. image:: https://codeclimate.com/github/mateuspontesm/rl-agents/badges/gpa.svg
        :target: https://codeclimate.com/github/mateuspontesm/rl-agents
        :alt: CodeClimate Quality Status

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
        :target: https://github.com/ambv/black

Implementation of various reinforcement learning methods.


* Free software: BSD 3-Clause 'New' or 'Revised' License

* Documentation: https://rl-agents.readthedocs.io.



Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `mateuspontesm/cookiecutter-poetry`_ project template,
a fork of `johanvergeer/cookiecutter-poetry`_ project template

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`johanvergeer/cookiecutter-poetry`: https://github.com/johanvergeer/cookiecutter-poetry
.. _`mateuspontesm/cookiecutter-poetry`: https://github.com/mateuspontesm/cookiecutter-poetry
